# Documentation

This directory contains developer and user documentation for the Navam project.

## Files

- **[development.md](development.md)** - Development guide including package synchronization process
- More documentation files will be added as the project grows

## Quick Links

- [Main README](../README.md) - Project overview and installation
- [Package Scripts](../scripts/) - Development automation scripts
- [Source Code](../src/) - Package source code